'use client';
import { z } from 'zod';
import { zodResolver } from '@hookform/resolvers/zod';
import { useForm } from 'react-hook-form';
import { getProfile, updateProfile, uploadFile } from '@/lib/actions';
import { useState, useEffect, useRef } from 'react';
import type { Profile } from '@/utils/supabase';
import {
  Button,
  Form,
  FormControl,
  FormDescription,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
  Input,
} from '@/components/ui';
import { toast } from 'sonner';
import { Pencil, User } from 'lucide-react'

const formSchema = z.object({
  full_name: z.string().min(5, {
    message: 'Full name is required & must be at least  5 characters.'
  }),
  email: z.string().email(),
});

const ProfilePage = () => {
  const [profile, setProfile] = useState<Profile | undefined>(undefined);
  const [isLoading, setIsLoading] = useState(true);
  const [isUploading, setIsUploading] = useState(false);
  const fileInputRef = useRef<HTMLInputElement>(null);


  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      full_name: '',
      email: '',
    },
  });

  useEffect(() => {
    const fetchProfile = async () => {
      try {
        setIsLoading(true);
        const profileResponse = await getProfile();
        if (!profileResponse.success)
          throw new Error('Profile response unsuccessful');
        setProfile(profileResponse.data);
        form.reset({
          full_name: profileResponse.data.full_name ?? '',
          email: profileResponse.data.email ?? '',
        });
      } catch (error) {
        console.error('Error getting profile:', error);
        toast.error('Failed to load profile data');
      } finally {
        setIsLoading(false);
      }
    };
    fetchProfile().catch((error) => {
      console.error('Error getting profile:', error);
    });
  }, [form]);

  const handleAvatarClick = () => {
    fileInputRef.current?.click();
  };

  const handleFileChange = async (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0];
    if (!file) return;
    try {

    } catch (error) {

    }
  };

  const onSubmit = async (values: z.infer<typeof formSchema>) => {
    try {
      setIsLoading(true);
      const result = await updateProfile({
        full_name: values.full_name,
        email: values.email,
      });

      if (!result.success) {
        throw new Error(result.error ?? 'Failed to update profile');
      }
      setProfile(result.data);
      toast.success('Profile updated successfully!');
    } catch (error) {
      console.error('Error updating profile: ', error);
    } finally {
      setIsLoading(false);  
    }
  };

  return (
    <Form { ...form}>
      <form
        onSubmit={form.handleSubmit(onSubmit)}
        className='space-y-8'
      >
        <FormField
          control={form.control}
          name='full_name'
          render={({ field }) => (
            <FormItem>
              <FormLabel>Full Name</FormLabel>
              <FormControl>
                <Input {...field} />
              </FormControl>
              <FormDescription>
                Your public display name.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name='email'
          render={({ field }) => (
            <FormItem>
              <FormLabel>Email</FormLabel>
              <FormControl>
                <Input {...field} />
              </FormControl>
              <FormDescription>
                Your email address associated with your account.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <Button type='submit'>Save</Button>
      </form>
    </Form>
  );
};
export default ProfilePage;
